A dataset containing the meta-data about vaccine coverage observations.
Format
A [data.table()] with 750 rows and 6 columns:
obs_id, a number, the observation (foreign key to observations)loc_id, a string, the location (foreign key to locations)cohort, a number, the birth cohortage, a number, the age of cohort at time of observationdose, a number, which dose the observation concernsweight, a number (0-1), fraction of the observation this row represents