Skip to contents

Signal a warning if a condition is met with formatted message

Usage

warn_fmt_if(cond, fmt, ..., n = 1L)

Arguments

cond

Logical expression to evaluate.

fmt

Character format string for sprintf().

...

Additional arguments passed to sprintf().

n

Frame offset integer specifying call stack depth for call attribution (default 1L). If n <= 0L, call attribution is suppressed (NULL).

Value

Logical scalar indicating whether cond evaluated to TRUE.