Check observations objects
Usage
check_observations(observations)
Arguments
- observations
a data.frame with:
nonnegative integer positive column
positive integer sample_n column, which must be greater than or equal
to the positive column
optionally, an id column, 1:size(observations)
Value
the observation object, possibly changed in place to cast columns
to integers and add the id column if not original present. Will error
if the column requirements are not satisfied.