A dataset containing vaccine coverage observations.
Format
A [data.table()] with 698 rows and 4+ columns:
obs_id, a number, the observation id (primary key)positive, a number, how many individuals had the vaccinesample_n, a number, the number of individuals in the observationscensored, a number, 1 ifpositiveis right censored andNAif uncensored... assorted other columns that are irrelevant to use as observations arg