Skip to contents

This function encapsulates option passing to the stan sampler, with the exception of the model object, which is passed in imugap_options.

Usage

stan_options(...)

Arguments

...

Arguments passed on to rstan::sampling

object

An object of class stanmodel.

Value

a list of arguments matching rstan::sampling() inputs