This function encapsulates option passing to the stan sampler.
Arguments
- object
An object of class
stanmodel.- ...
Arguments passed on to
rstan::sampling
Value
a list of arguments matching rstan::sampling() inputs
This function encapsulates option passing to the stan sampler.
An object of class stanmodel.
Arguments passed on to rstan::sampling
a list of arguments matching rstan::sampling() inputs