Skip to contents

A dataset specifying the target populations for coverage prediction, generated by calling create_target() on the simulated fit object fit_sim along with arguments for which locations, cohorts, and ages to target. Includes locations which were not present in the original simulated observations, namely the State and County levels.

Usage

target_sim

Format

A [data.table()] with 1008 rows and 7 columns:

  • obs_c_id, a number, the target observation/combination ID (primary key)

  • loc_id, a string, the location ID

  • age, a number, the age

  • cohort, a number, the birth cohort

  • dose, a number, the vaccine dose (1 or 2)

  • weight, a number, the weight of the prediction component (always 1)

  • loc_c_id, a number, the compiled location ID